// package dein.package;

/**
 * Klassenname: SylkCell<BR>
 *<BR>
 * Subsystem: Frontend Export Excel<BR>
 *<BR>
 * Zugeh&ouml;riger UseCase: Excel-Export Posten sowie Summen- und Zinsberechnung Posten<BR>
 *<BR>
 * Subklasse f&uuml;r den Excel-Export mit der Klasse Sylk.<BR>
 * Enth&auml;lt eine einzelne Zelle eines Sylk-Excel-Sheets.<BR>
 * SylkCell wird von der Klasse Sylk verwendet.<BR>
 *
 * @author Heiner K&uuml;cker
 * @version $Id$
 */
public class SylkCell {

  /**
   * Zelle enth&auml;lt einen Wert
   */
  public static final int CELL_VALUE = 0;

  /**
   * Zelle enth&auml;lt eine Formel
   */
  public static final int CELL_FORMULA = 1;

  /**
   *<BR>
   * Zelle ist Default ausgerichtet<BR>
   * numerische Zellen rechtsb&uuml;ndig<BR>
   * Textzellen linksb&uuml;ndig
   */
  public static final int ALIGN_DEFAULT = 0;

  /**
   * Zelle ist rechtsausgerichtet
   */
  public static final int ALIGN_RIGHT = 1;

  /**
   * Zelle ist zentriert
   */
  public static final int ALIGN_CENTER = 2;

  /**
   * Zelle ist linksausgerichtet
   */
  public static final int ALIGN_LEFT = 3;

  /**
   * Zellinhalt
   */
  private String strClValue = null;

  /**
   * Merker ob Zelle Wert oder Formel enth&auml;lt
   */
  private int iClStatus = CELL_VALUE;

  /**
   * Merker f&uuml;r Zell-Alignment
   */
  private int iClAlignment = SylkCell.ALIGN_DEFAULT;

  /**
   * Konstruktor
   */
  public SylkCell() {
    super();
  }

  /**
   * Zellinhalt holen
   *
   * @return Zellinhalt
   */
  public String getValue() {
    return strClValue;
  }

  /**
   * Zellinhalt setzen
   *
   * @param strPaValue zu setzender Inhalt als String
   */
  public void setValue(String strPaValue) {
    strClValue = strPaValue;
  }

  /**
   * Abfragen ob Zelle Wert oder Formel enth&auml;lt ( siehe entsprechende Kostanten )
   *
   * @return Status der Zelle als int-Wert
   */
  public int getStatus() {
    return iClStatus;
  }

  /**
   * Setzen, ob Zelle Wert oder Formel enth&auml;lt ( siehe entsprechende Kostanten )
   *
   * @param iPaStatus zu setzender Status ( hier entsprechende Konstanten verwenden )
   */
  public void setStatus(int iPaStatus) {
    iClStatus = iPaStatus;
  }

  /**
   * Abfragen Zell-Alignment ( siehe entsprechende Kostanten )
   *
   * @return Zell-Alignment als int-Wert
   */
  public int getAlignment() {
    return iClAlignment;
  }

  /**
   * Setzen Zell-Alignment ( siehe entsprechende Kostanten )
   *
   * @param iPaAlignment zu setzende Ausrichtung ( hier entsprechende Konstanten verwenden )
   */
  public void setAlignment(int iPaAlignment) {
    iClAlignment = iPaAlignment;
  }

  /**
   * Destruktor
   *
   * @throws Throwable
   */
  protected void finalize()
      throws Throwable {
    super.finalize();
  } // end Destruktor

} // end class SylkCell
